/*
 * Copyright 2023 RethinkDNS and its authors
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.celzero.bravedns.database

import androidx.room.Transaction

class ODoHEndpointRepository(private val endpointDao: ODoHEndpointDAO) {

    @Transaction
    suspend fun update(endpoint: ODoHEndpoint) {
        endpointDao.removeConnectionStatus()
        endpointDao.update(endpoint)
    }

    suspend fun insertAsync(endpoint: ODoHEndpoint) {
        endpointDao.insert(endpoint)
    }

    suspend fun deleteOlderData(date: Long) {
        endpointDao.deleteOlderData(date)
    }

    suspend fun deleteODoHEndpoint(id: Int) {
        endpointDao.deleteODoHEndpoint(id)
    }

    suspend fun removeConnectionStatus() {
        endpointDao.removeConnectionStatus()
    }

    suspend fun getConnectedODoH(): ODoHEndpoint? {
        return endpointDao.getConnectedODoH()
    }

    suspend fun getCount(): Int {
        return endpointDao.getCount()
    }
}
